<h1 align="center">
  Wikidata Curation Tools
</h1>

<p align="center">
    <a href="https://github.com/lubianat/wdcuration/actions?query=workflow%3ATests">
        <img alt="Tests" src="https://github.com/lubianat/wdcuration/workflows/Tests/badge.svg" />
    </a>
    <a href="https://pypi.org/project/wdcuration">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/wdcuration" />
    </a>
    <a href="https://pypi.org/project/wdcuration">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/wdcuration" />
    </a>
    <a href="https://github.com/lubianat/wdcuration/blob/main/LICENSE">
        <img alt="PyPI - License" src="https://img.shields.io/pypi/l/wdcuration" />
    </a>
    <a href='https://wdcuration.readthedocs.io/en/latest/?badge=latest'>
        <img src='https://readthedocs.org/projects/wdcuration/badge/?version=latest' alt='Documentation Status' />
    <a href='https://github.com/psf/black'>
        <img src='https://img.shields.io/badge/code%20style-black-000000.svg' alt='Code style: black' />
    </a>
    <a href="https://github.com/lubianat/wdcuration/blob/main/.github/CODE_OF_CONDUCT.md">
        <img src="https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg" alt="Contributor Covenant"/>
    </a>
</p>

Utils for curating unstructured data into Wikidata

## 💪 Getting Started

> TODO show in a very small amount of space the **MOST** useful thing your package can do.
> Make it as short as possible! You have an entire set of docs for later.


## 🚀 Installation

The most recent release can be installed from
[PyPI](https://pypi.org/project/wdcuration/) with:

```bash
$ pip install wdcuration
```

The most recent code and data can be installed directly from GitHub with:

```bash
$ pip install git+https://github.com/lubianat/wdcuration.git
```

## 👐 Contributing

Contributions, whether filing an issue, making a pull request, or forking, are appreciated. See
[CONTRIBUTING.md](https://github.com/lubianat/wdcuration/blob/master/.github/CONTRIBUTING.md) for more information on getting involved.

## 👋 Attribution

This package was created with Cookiecutter and the `audreyr/cookiecutter-pypackage` project template.

### ⚖️ License

The code in this package is licensed under the MIT license.
